@@ -1,5 +1,5 @@
-#  tests for pygobject-3.40.1-py37h7f6e4f1_2 (this is a generated file);
-print('===== testing package: pygobject-3.40.1-py37h7f6e4f1_2 =====');
+#  tests for pygobject-3.42.0-py37h7f6e4f1_1 (this is a generated file);
+print('===== testing package: pygobject-3.42.0-py37h7f6e4f1_1 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
 import gi
@@ -10,10 +10,13 @@ assert(31 == GLib.Date.get_days_in_month(GLib.DateMonth.JANUARY, 2000))
 
 #  --- run_test.py (end) ---
 
-print('===== pygobject-3.40.1-py37h7f6e4f1_2 OK =====');
+print('===== pygobject-3.42.0-py37h7f6e4f1_1 OK =====');
 print("import: 'gi'")
 import gi
 
+print("import: 'gi.pygtkcompat'")
+import gi.pygtkcompat
+
 print("import: 'gi.repository.GLib'")
 import gi.repository.GLib
 
